@@ -1,11 +1,8 @@
+#include <jmp-config.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <jvmpi.h>
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 #include <arena.h>
 
@@ -42,7 +39,7 @@ int arena_cmp_func (void* arena1, void* arena2) {
 }
 
 void arena_print (arena* arena) {
-    fprintf (stdout, "ARENA: %d, %s\n", arena->arena_id, arena->arena_name);
+    fprintf (stdout, "ARENA: %d, %s\n", PRINTF_JINT_CAST arena->arena_id, arena->arena_name);
 }
 
 void arena_set_arena_id (arena *a, jint id) {
