@@ -1,23 +1,27 @@
+#include <jmp-config.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
-#include <jvmpi.h>
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#ifdef HAVE_UNISTD_H
+ #include <unistd.h>
 #endif
+#ifdef HAVE_WINDOWS_H
+ #include <windows.h>
+#endif
+
+#include <jvmpi.h>
 
 #include <cls.h>
 #include <translate.h>
 #include <filter.h>
 
+#ifndef max	/* exists in WIN32 w32api/windef.h */
 #define max(a,b) (a) > (b) ? (a) : (b);
+#endif
 
-/* TODO, get a dynamic size... */
-static char buf[1000];
 
-static void copy_fields (const jint n_statics, field* fields, const JVMPI_Field* origs) {
+static void copy_fields (const jint n_statics, field* fields, const JVMPI_Field* origs, char *buf) {
     jint i;
     size_t l;
     for (i = 0; i < n_statics; i++) {
@@ -68,6 +72,8 @@ cls* cls_new (const char* class_name, const char* source_name, const jobjectID c
 	      const jint n_interfaces, 
 	      const jint n_statics, const JVMPI_Field* statics,              /* static variables. */
 	      const jint n_instances, const JVMPI_Field* instances) {        /* local variables. */
+    /* TODO, get a dynamic size... */
+    char buf[1000];
     cls* c;
     size_t l2 = 1, l3 = 1;
     
@@ -118,8 +124,8 @@ cls* cls_new (const char* class_name, const char* source_name, const jobjectID c
 	cls_free (c);
 	return NULL;
     }
-    copy_fields (n_statics, c->statics, statics);
-    copy_fields (n_instances, c->instances, instances);
+    copy_fields (n_statics, c->statics, statics, buf);
+    copy_fields (n_instances, c->instances, instances, buf);
     c->super = NULL;
     c->filtered = filter_class_name (c->class_name);
     return c;
@@ -162,68 +168,74 @@ int cls_cmp_func (void* c1, void* c2) {
 }
 
 void cls_print (cls* c) {
+#ifdef unix
     pid_t p = getpid ();
+#endif
+#ifdef WIN32
+    DWORD p = GetCurrentProcessId();	/* wants %ld */
+#endif
     if (c->usage.totalInstances > 0)
 	fprintf (stdout, "%d: CLASS: %s, %p, interfaces: %d, statics: %d instances: %d, %ld, %ld\n",
-		 p, c->class_name, c->class_id, c->n_interfaces, c->n_statics, c->n_instances,
+		 p, c->class_name, c->class_id, PRINTF_JINT_CAST c->n_interfaces,
+		 PRINTF_JINT_CAST c->n_statics, PRINTF_JINT_CAST c->n_instances,
 		 c->usage.totalAlloced, c->usage.totalInstances);
 }
 
-inline char* cls_get_class_name (cls* c) {
+INLINE char* cls_get_class_name (cls* c) {
     return c->class_name;
 }
 
-inline char* cls_get_source_name (cls* c) {
+INLINE char* cls_get_source_name (cls* c) {
     return c->source_name;
 }
 
-inline char* cls_get_name (cls* c) {
+INLINE char* cls_get_name (cls* c) {
     if (c == NULL)
 	return NULL;
     return c->name;
 }
 
-inline jobjectID cls_get_class_id (cls* c) {
+INLINE jobjectID cls_get_class_id (cls* c) {
     return c->class_id;
 }
 
-inline void cls_set_class_id (cls* c, jobjectID class_id) {
+INLINE void cls_set_class_id (cls* c, jobjectID class_id) {
     c->class_id = class_id;
 }
 
-inline long cls_get_instances (cls* c) {
+INLINE long cls_get_instances (cls* c) {
     return c->usage.totalInstances;
 }
 
-inline void cls_set_instances (cls* c, long l) {
+INLINE void cls_set_instances (cls* c, long l) {
     c->usage.totalInstances = l;
 }
 
-inline long cls_get_max_instances (cls* c) {
+INLINE long cls_get_max_instances (cls* c) {
     return c->usage.maximumInstances;
 }
 
-inline void cls_set_max_instances (cls* c, long l) {
+INLINE void cls_set_max_instances (cls* c, long l) {
     c->usage.maximumInstances = l;
 }
 
-inline long cls_get_size (cls* c) {
+INLINE long cls_get_size (cls* c) {
     return c->usage.totalAlloced;
 }
 
-inline long cls_get_total_gc (cls* c) {
+INLINE long cls_get_total_gc (cls* c) {
     return c->usage.totalGC;
 }
 
-inline long cls_get_tenure (cls* c) {
+INLINE long cls_get_tenure (cls* c) {
     return c->usage.totalAllocLevel;
 }
 
-inline void cls_set_size (cls* c, long l) {
+INLINE void cls_set_size (cls* c, long l) {
     c->usage.totalAlloced = l;
 }
 
-inline void cls_object_alloc (cls* c, jint size, jint gc_level) {
+INLINE void cls_object_alloc (cls* c, jint size, jint gc_level) {
     c->usage.totalInstances++;
     c->usage.totalAlloced += size;
     c->usage.totalAllocLevel += gc_level;
@@ -232,7 +244,7 @@ inline void cls_object_alloc (cls* c, jint size, jint gc_level) {
     c->modified = 1;
 }
 
-inline void cls_object_free (cls* c, jint size, jint gc_level) {
+INLINE void cls_object_free (cls* c, jint size, jint gc_level) {
     c->usage.totalInstances--;
     c->usage.totalAlloced -= size;
     c->usage.totalGC++;
@@ -240,13 +252,13 @@ inline void cls_object_free (cls* c, jint size, jint gc_level) {
     c->modified = 1;
 }
 
-inline void cls_object_free_not_gc (cls* c, jint size) {
+INLINE void cls_object_free_not_gc (cls* c, jint size) {
     c->usage.totalInstances--;
     c->usage.totalAlloced -= size;
     c->modified = 1;
 }
 
-inline void cls_reset_count (cls* c) {
+INLINE void cls_reset_count (cls* c) {
     c->restorer.totalAlloced += c->usage.totalAlloced;
     c->usage.totalAlloced = 0;
     c->restorer.totalInstances += c->usage.totalInstances;
@@ -258,7 +270,7 @@ inline void cls_reset_count (cls* c) {
     c->modified = 1;
 }
 
-inline void cls_restore_count (cls* c) {
+INLINE void cls_restore_count (cls* c) {
     c->usage.totalAlloced += c->restorer.totalAlloced;
     c->restorer.totalAlloced = 0;
     c->usage.totalInstances += c->restorer.totalInstances;
@@ -270,27 +282,27 @@ inline void cls_restore_count (cls* c) {
     c->modified = 1;
 }
 
-inline void cls_set_super (cls* c, cls* super) {
+INLINE void cls_set_super (cls* c, cls* super) {
     c->super = super;
 }
 
-inline cls* cls_get_super (cls* c) {
+INLINE cls* cls_get_super (cls* c) {
     return c->super;
 }
 
-inline void cls_set_filtered (cls* c, int filtered) {
+INLINE void cls_set_filtered (cls* c, int filtered) {
     c->filtered = filtered;
 }
 
-inline int cls_get_filtered (cls* c) {
+INLINE int cls_get_filtered (cls* c) {
     return c->filtered;
 }
 
-inline int cls_check_modified (cls* c) {
+INLINE int cls_check_modified (cls* c) {
     return c->modified;
 }
 
-inline void cls_set_modified (cls* c, int flag) {
+INLINE void cls_set_modified (cls* c, int flag) {
     c->modified = flag;
 }
 
