@@ -71,90 +71,90 @@ int cls_cmp_func (void* c1, void* c2);
 void cls_print (cls* c);
 
 /** Get the class name of the class. */
-inline char* cls_get_class_name (cls* c);
+INLINE char* cls_get_class_name (cls* c);
 
 /** Get the source file name for the class. */
-inline char* cls_get_source_name (cls* c);
+INLINE char* cls_get_source_name (cls* c);
 
 /** Get the human readable name of the class. */
-inline char* cls_get_name (cls* c);
+INLINE char* cls_get_name (cls* c);
 
 /** Get the id of the class. */
-inline jobjectID cls_get_class_id (cls* c);
+INLINE jobjectID cls_get_class_id (cls* c);
 
 /** Set the class id to the new id. */
-inline void cls_set_class_id (cls* c, jobjectID class_id);
+INLINE void cls_set_class_id (cls* c, jobjectID class_id);
 
 /** Get the current number of instances of this class. */
-inline long cls_get_instances (cls* c);
+INLINE long cls_get_instances (cls* c);
 
 /** Set the current number of instances of this class. 
  * Useful for relative counting. 
  */
-inline void cls_set_instances (cls* c, long l);
+INLINE void cls_set_instances (cls* c, long l);
 
 /** Get the maximum number of simultanious instances of this class.. */
-inline long cls_get_max_instances (cls* c);
+INLINE long cls_get_max_instances (cls* c);
 
 /** Set the maximum number of simultanious instances of this class. 
  *  Useful for relative counting. 
  */
-inline void cls_set_max_instances (cls* c, long l);
+INLINE void cls_set_max_instances (cls* c, long l);
 
 /** Get the number of bytes instances of this class currently use. */
-inline long cls_get_size (cls* c);
+INLINE long cls_get_size (cls* c);
 
 /* Set the number of bytes this class is currently using. 
  * Useful for relative counting. 
  */
-inline void cls_set_size (cls* c, long l);
+INLINE void cls_set_size (cls* c, long l);
 
 /** Get the total number of instances of this class that 
  *  have been garbage collected.
  */
-inline long cls_get_total_gc (cls* c);
+INLINE long cls_get_total_gc (cls* c);
 
 /** Get the tenure number for this class. 
  *  The returned number is the sum of the gc-level for all 
  *  instances of this class.
  */
-inline long cls_get_tenure (cls* c);
+INLINE long cls_get_tenure (cls* c);
 
 /** Add a new instance with given size to the current statistics. */
-inline void cls_object_alloc (cls* c, jint size, jint gc_level);
+INLINE void cls_object_alloc (cls* c, jint size, jint gc_level);
 
 /** An object has been freed. */
-inline void cls_object_free (cls* c, jint size, jint gc_level);
+INLINE void cls_object_free (cls* c, jint size, jint gc_level);
 
 /** An object has been freed. 
  *  The object was not GC:ed but rather removed due to heap dump 
  *  or event enable/disable.
  */
-inline void cls_object_free_not_gc (cls* c, jint size);
+INLINE void cls_object_free_not_gc (cls* c, jint size);
 
 /** Reset counters to zero... */
-inline void cls_reset_count (cls* c);
+INLINE void cls_reset_count (cls* c);
 
 /** Restore counters to real values. */
-inline void cls_restore_count (cls* c);
+INLINE void cls_restore_count (cls* c);
 
 /** Set the super class. */
-inline void cls_set_super (cls* c, cls* super);
+INLINE void cls_set_super (cls* c, cls* super);
 
 /** Get the super class */
-inline cls* cls_get_super (cls* c);
+INLINE cls* cls_get_super (cls* c);
 
 /** Set the filtered mode of the given class. */
-inline void cls_set_filtered (cls* c, int filtered);
+INLINE void cls_set_filtered (cls* c, int filtered);
 
 /** Get the filtered mode of the given class. */
-inline int cls_get_filtered (cls* c);
+INLINE int cls_get_filtered (cls* c);
 
 /** Check if this class has changed since last call. */
-inline int cls_check_modified (cls* c);
+INLINE int cls_check_modified (cls* c);
 
 /** Set updated status of this class. */
-inline void cls_set_modified (cls* c, int flag);
+INLINE void cls_set_modified (cls* c, int flag);
 
 /** Get the field type as a readable string. */
 char* get_field_type (field* f);
