@@ -1,22 +1,30 @@
+#include <jmp-config.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <limits.h>
-#include <jmp.h>
 #ifdef unix
 #ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
+#  include <sys/types.h>
 #endif
 #include <netinet/in.h>
 #endif /* unix */
-#include <heap_dump.h>
+
+#include <jmp.h>
+#include <jmp-debug.h>
 #include <obj.h>
 #include <cls.h>
 #include <hash.h>
-#include <ui.h>
-#include <jthread.h>
+#include <jmpthread.h>
+#include <heap_dump.h>
+#ifdef HAVE_WIN32COMPAT_H
+ #include <win32compat.h>
+#endif
 
-#ifdef _WIN32
+#include <ui_gtk.h>
+
+#if (defined(_WIN32) && (!defined(HAVE_WINSOCK_H) && !defined(HAVE_WINSOCK2_H)))
 /* TODO get theese from some header instead. */
 unsigned long int ntohl (unsigned long int x) {
     asm ("xchgb %b0,%h0\n\t"	
@@ -56,6 +64,7 @@ static void generate_bin_dump (char* file_name, char* begin, char* end) {
 }
 #endif /* JMPDEBUG */
 
+
 static int heap_jmphash_cmp (void* ol1, void* ol2) {
     object_link* o1 = (object_link*)ol1;
     object_link* o2 = (object_link*)ol2;
@@ -138,7 +147,18 @@ static jint get_u4 (char** p) {
     return ntohl (i);
 }
 
-static jint get_u2 (char** p) {
+static jfloat get_u4_as_float (char** p) {
+    /* UNTESTED MAYBE BROKEN */
+    union {
+      jfloat jf;
+      unsigned char b[4];
+    } u;
+    memcpy (&u.b, *p, sizeof (u.jf));
+    *p += 4;
+    return u.jf;
+}
+
+static unsigned short get_u2 (char** p) {
     unsigned short u2;
     memcpy (&u2, *p, sizeof (u2));
     *p += sizeof (u2);
@@ -156,12 +176,12 @@ static void dump_triplet (FILE* fp, char* prefix, char** p) {
     jobjectID oid = get_pointer (p);
     JNIEnv* env = get_pointer (p);
     jint u4 = get_u4 (p);
-    fprintf (fp, "%s: oid=%p, env=%p, frame#=%d\n", prefix, oid, env, u4);
+    fprintf (fp, "%s: oid=%p, env=%p, frame#=%d\n", prefix, oid, env, PRINTF_JINT_CAST u4);
 }
 
 static void dump_booleans (FILE* fp, jobjectID oid, jint size, char** p) {
     int i;
-    fprintf (fp, "oid=%p[%d] => Z{", oid, size);
+    fprintf (fp, "oid=%p[%d] => Z{", oid, PRINTF_JINT_CAST size);
     for (i = 0; i < size; i++) {  
 	unsigned char u1 = get_u1 (p);
 	if (i > 0)
@@ -173,7 +193,7 @@ static void dump_booleans (FILE* fp, jobjectID oid, jint size, char** p) {
 
 static void dump_bytes (FILE* fp, jobjectID oid, jint size, char** p) {
     int i;
-    fprintf (fp, "oid=%p[%d] => B{", oid, size);
+    fprintf (fp, "oid=%p[%d] => B{", oid, PRINTF_JINT_CAST size);
     for (i = 0; i < size; i++) {  
 	unsigned char u1 = get_u1 (p);
 	if (i > 0)
@@ -185,7 +205,7 @@ static void dump_bytes (FILE* fp, jobjectID oid, jint size, char** p) {
 
 static void dump_chars (FILE* fp, jobjectID oid, jint size, char** p) {
     int i;
-    fprintf (fp, "oid=%p[%d] => C{", oid, size);
+    fprintf (fp, "oid=%p[%d] => C{", oid, PRINTF_JINT_CAST size);
     for (i = 0; i < size; i++) {  
 	unsigned short u2 = get_u2 (p);
 	if (i > 0)
@@ -197,7 +217,7 @@ static void dump_chars (FILE* fp, jobjectID oid, jint size, char** p) {
 
 static void dump_shorts (FILE* fp, jobjectID oid, jint size, char** p) {
     int i;
-    fprintf (fp, "oid=%p[%d] => S{", oid, size);
+    fprintf (fp, "oid=%p[%d] => S{", oid, PRINTF_JINT_CAST size);
     for (i = 0; i < size; i++) {  
 	unsigned short u2 = get_u2 (p);
 	if (i > 0)
@@ -209,35 +229,35 @@ static void dump_shorts (FILE* fp, jobjectID oid, jint size, char** p) {
 
 static void dump_ints (FILE* fp, jobjectID oid, jint size, char** p) {
     int i;
-    fprintf (fp, "oid=%p[%d] => I{", oid, size);
+    fprintf (fp, "oid=%p[%d] => I{", oid, PRINTF_JINT_CAST size);
     for (i = 0; i < size; i++) {  
 	jint u4 = get_u4 (p);
 	if (i > 0)
 	    fprintf (fp, ", ");
-	fprintf (fp, "%d", u4);
+	fprintf (fp, "%d", PRINTF_JINT_CAST u4);
     }
     fprintf (fp, "}\n"); 
 }
 
 static void dump_longs (FILE* fp, jobjectID oid, jint size, char** p) {
     int i;
-    fprintf (fp, "oid=%p[%d] => J{", oid, size);
+    fprintf (fp, "oid=%p[%d] => J{", oid, PRINTF_JINT_CAST size);
     for (i = 0; i < size; i++) {  
 	jint u41 = get_u4 (p);
 	jint u42 = get_u4 (p);
 	if (i > 0)
 	    fprintf (fp, ", ");
 	if (u42 != 0) 
-	    fprintf (fp, "0x%08x%08x", u42, u41);
+	    fprintf (fp, "0x%08x%08x", PRINTF_JINT_CAST u42, PRINTF_JINT_CAST u41);
 	else
-	    fprintf (fp, "0x%d", u41);
+	    fprintf (fp, "0x%d", PRINTF_JINT_CAST u41);
     }
     fprintf (fp, "}\n"); 
 }
 
 static void dump_floats (FILE* fp, jobjectID oid, jint size, char** p) {
     int i;
-    fprintf (fp, "oid=%p[%d] => F{", oid, size);
+    fprintf (fp, "oid=%p[%d] => F{", oid, PRINTF_JINT_CAST size);
     for (i = 0; i < size; i++) {  
 	jint u4 = get_u4 (p);
 	if (i > 0)
@@ -249,13 +269,13 @@ static void dump_floats (FILE* fp, jobjectID oid, jint size, char** p) {
 
 static void dump_doubles (FILE* fp, jobjectID oid, jint size, char** p) {
     int i;
-    fprintf (fp, "oid=%p[%d] => D{", oid, size);
+    fprintf (fp, "oid=%p[%d] => D{", oid, PRINTF_JINT_CAST size);
     for (i = 0; i < size; i++) {  
 	jint u41 = get_u4 (p);
 	jint u42 = get_u4 (p);
 	if (i > 0)
 	    fprintf (fp, ", ");
-	fprintf (fp, "0x%d%d", u42, u41);
+	fprintf (fp, "0x%d%d", PRINTF_JINT_CAST u42, PRINTF_JINT_CAST u41);
     }
     fprintf (fp, "}\n");     
 }
@@ -264,7 +284,7 @@ static void dump_objects (FILE* fp, jobjectID oid, jobjectID clz,
 			  jint size, char** p, hashtab* heap_hash) {
     int i;
     cls* c = get_class (clz);
-    fprintf (fp, "oid=%p[%d] => %p,%s{", oid, size, clz, c ? c->name : "<unknown>");
+    fprintf (fp, "oid=%p[%d] => %p,%s{", oid, PRINTF_JINT_CAST size, clz, c ? c->name : "<unknown>");
     for (i = 0; i < size; i++) {  
 	jobjectID o = get_pointer (p);
 	if (i > 0)
@@ -317,19 +337,19 @@ static jobjectID get_variable (FILE* fp, char** p, field* f) {
     case JVMPI_INT: {
 	jint u4;
 	u4 = get_u4 (p);
-	fprintf (fp, "I%d", u4);
+	fprintf (fp, "I%d", PRINTF_JINT_CAST u4);
 	break;
     }
     case JVMPI_LONG: {
 	jint  u41, u42;
 	u41 = get_u4 (p);
 	u42 = get_u4 (p);
-	fprintf (fp, "J%08x%08x", u42, u41);
+	fprintf (fp, "J%08x%08x", PRINTF_JINT_CAST u42, PRINTF_JINT_CAST u41);
 	break;
     }
     case JVMPI_FLOAT: {
 	jfloat u4;
-	u4 = get_u4 (p);
+	u4 = get_u4_as_float (p);
 	fprintf (fp, "F%f", u4);
 	break;
     }
@@ -337,7 +357,7 @@ static jobjectID get_variable (FILE* fp, char** p, field* f) {
 	jint  u41, u42;
 	u41 = get_u4 (p);
 	u42 = get_u4 (p);
-	fprintf (fp, "D%x%x", u42, u41);
+	fprintf (fp, "D%x%x", PRINTF_JINT_CAST u42, PRINTF_JINT_CAST u41);
 	break;
     }
     }
@@ -403,7 +423,7 @@ void heap_dump_2 (char* dumpdir,
     FILE* fp = get_heap_dump_file (dumpdir);
     
     fprintf (fp, "heap_dump: %d, %p, %p, %d, %p\n", 
-	     dump_level, begin, end, num_traces, traces);
+	     dump_level, begin, end, PRINTF_JINT_CAST num_traces, traces);
     fprintf (fp, "void*; %d, u4: %d, u2: %d, u1: %d\n", 
 	     sizeof (void*), sizeof (jint), sizeof (unsigned short), sizeof (unsigned char));
     
@@ -494,7 +514,7 @@ void heap_dump_2 (char* dumpdir,
 	    
 	    fprintf (fp, "class_dump: class %p (%p) => %s, %p => %s, %d\n", 
 		     clz, c, c->name,  super, (supercls ? supercls->name : ""), 
-		     instance_size);
+		     PRINTF_JINT_CAST instance_size);
 	    /* read the interfaces. */
 	    for (i = 0; i < c->n_interfaces; i++) {
 		ifacep = get_pointer (&p);
@@ -511,7 +531,7 @@ void heap_dump_2 (char* dumpdir,
 		jshort constant_pool_index = get_u2 (&p);
 		ty = get_u1 (&p);
 		const_pool_obj = get_pointer (&p);
-		fprintf (fp, "\tconstant pool[%d] => %d, %p\n", i, 
+		fprintf (fp, "\tconstant pool[%d] => %d, %p\n", PRINTF_JINT_CAST i, 
 			 constant_pool_index, const_pool_obj);
 	    }
 	    
@@ -542,12 +562,12 @@ void heap_dump_2 (char* dumpdir,
 	    u4 = get_u4 (&p);
 	    pe = p + u4;
 	    fprintf (fp, "instance dump (%p): %p => %s, %d\n", 
-		     oid, clz, (c ? c->name : "?"), u4);
+		     oid, clz, (c ? c->name : "?"), PRINTF_JINT_CAST u4);
 	    while (c != NULL) {
 		jobjectID sobj;
 		if (c->n_instances > 0) {
 		    fprintf (fp, "class '%s' has %d variables...\n", 
-			     c->name, c->n_instances);
+			     c->name, PRINTF_JINT_CAST c->n_instances);
 		}
 		for (i = 0; i < c->n_instances; i++) {
 		    sobj = get_variable (fp, &p, &c->instances[i]);
@@ -560,7 +580,7 @@ void heap_dump_2 (char* dumpdir,
 		c = cls_get_super (c);
 	    }
 	    if (p != pe) {
-		fprintf (stderr, "doh, failed to read instance variables size: %d.....\n", u4);
+		fprintf (stderr, "doh, failed to read instance variables size: %d.....\n", PRINTF_JINT_CAST u4);
 		p = pe;
 	    }
 	    break;
@@ -678,7 +698,7 @@ void object_dump (jint data_len, char *data) {
     jint i;
 
     if (!p) {
-	fprintf (stderr, "object_dump: got NULL data (%p), data_len=%d\n", p, data_len);
+	fprintf (stderr, "object_dump: got NULL data (%p), data_len=%d\n", p, PRINTF_JINT_CAST data_len);
 	return;
     }
 
@@ -749,7 +769,7 @@ void object_dump (jint data_len, char *data) {
 	    c = cls_get_super (c);
 	}
 	if (p != pe) {
-	    fprintf (stderr, "doh, failed to read instance variables size: %d.....\n", u4);
+	    fprintf (stderr, "doh, failed to read instance variables size: %d.....\n", PRINTF_JINT_CAST u4);
 	    p = pe;
 	}
 	break;
@@ -902,7 +922,7 @@ hashtab* monitor_dump (char* begin,
 	    break;	    
 	}
 	owner = get_pointer (&p);
-	mi->owner = get_jthread (owner);
+	mi->owner = get_jmpthread (owner);
 	mi->entry_count = get_u4 (&p);
 	mi->num_waiting_to_enter = get_u4 (&p);
 	if (mi->num_waiting_to_enter) {
@@ -910,7 +930,7 @@ hashtab* monitor_dump (char* begin,
 		malloc (sizeof (*mi->waiting_to_enter) * mi->num_waiting_to_enter);
 	    for (i = 0; i < mi->num_waiting_to_enter; i++) {
 		JNIEnv* waiting_thread = get_pointer (&p);
-		mi->waiting_to_enter[i] = get_jthread (waiting_thread);
+		mi->waiting_to_enter[i] = get_jmpthread (waiting_thread);
 	    }
 	} else {
 	    mi->waiting_to_enter = NULL;
@@ -921,7 +941,7 @@ hashtab* monitor_dump (char* begin,
 		malloc (sizeof (*mi->waiting_to_enter) * mi->num_waiting_for_notify);
 	    for (i = 0; i < mi->num_waiting_for_notify; i++) {
 		JNIEnv* waiting_thread = get_pointer (&p);
-		mi->waiting_for_notify[i] = get_jthread (waiting_thread);
+		mi->waiting_for_notify[i] = get_jmpthread (waiting_thread);
 	    }
 	} else {
 	    mi->waiting_for_notify = NULL;
