@@ -50,12 +50,12 @@ typedef struct monitor_info monitor_info;
 struct monitor_info {
     char* name;
     void* id;
-    jthread* owner;
+    jmpthread* owner;
     jint entry_count;
     jint num_waiting_to_enter;
-    jthread** waiting_to_enter;
+    jmpthread** waiting_to_enter;
     jint num_waiting_for_notify;
-    jthread** waiting_for_notify;
+    jmpthread** waiting_for_notify;
 };
 
 /** Free a monitor info structure. */
