@@ -9,14 +9,6 @@
 #include <config.h>
 #endif
 
-#if ENABLE_NLS
-#  include <libintl.h>
-#  include <locale.h>
-#  define _(x) gettext(x)
-#else
-#  define _(x) (x)
-#endif
-
 /** These are standard type of objects, they are defined in there
  *  respective header files.
  */
@@ -24,7 +16,7 @@ typedef struct cls cls;
 typedef struct obj obj;
 typedef struct method method;
 typedef struct methodtime methodtime;
-typedef struct jthread jthread;
+typedef struct jmpthread jmpthread;
 typedef struct arena arena;
 typedef struct timerstack timerstack;
 typedef struct mvector mvector;
@@ -34,23 +26,25 @@ typedef struct mvector mvector;
 void get_backtrace ();
 #endif 
 
+extern JavaVM *JavaVM_jvm;
+
 /** Create a new monitor */
-JVMPI_RawMonitor jmp_create_monitor (char *);
+JVMPI_RawMonitor jvmpi_create_monitor (char *);
 
 /** Delete a monitor */
-void jmp_delete_monitor (JVMPI_RawMonitor);
+void jvmpi_delete_monitor (JVMPI_RawMonitor);
 
 /** Lock a monitor */
-void jmp_lock_monitor (JVMPI_RawMonitor);
+void jvmpi_lock_monitor (JVMPI_RawMonitor);
 
 /** Unlock a monitor */
-void jmp_unlock_monitor (JVMPI_RawMonitor);
+void jvmpi_unlock_monitor (JVMPI_RawMonitor);
 
 /** Wait for a monitor */
-void jmp_monitor_wait (JVMPI_RawMonitor, jlong milis);
+void jvmpi_monitor_wait (JVMPI_RawMonitor, jlong milis);
 
 /** Notify all waiting for a monitor */
-void jmp_monitor_notify_all (JVMPI_RawMonitor);
+void jvmpi_monitor_notify_all (JVMPI_RawMonitor);
 
 /** Get the jmp class object from its id. */
 cls*        get_class (const jobjectID class_id);
@@ -62,7 +56,7 @@ obj*        get_object (const jobjectID obj_id);
 method*     get_method (const jmethodID method_id);
 
 /** Get the jmp thread object from its id. */
-jthread*    get_jthread (const JNIEnv* env_id);
+jmpthread*    get_jmpthread (const JNIEnv* env_id);
 
 /** Get the jmp arena object from its id. */
 arena*      get_arena (const jint arena_id);
@@ -169,6 +163,7 @@ hashtab* run_monitor_dump ();
  */
 void cleanup_monitor_information ();
 
+#ifdef CONFIG_UI_GTK
 /** request that jmp dumps objects alloced in the given method. 
  * @param m the method that has alloced objects.
  */
@@ -193,6 +188,7 @@ void run_find_instance_owners (obj* o);
  * @param c the class of the instaces jmp should find owners for.
  */
 void run_owners_statistics (cls* c);
+#endif
 
 typedef void   (*string_callback) (obj*, void*);
 /** perform the given callback on each string. */
@@ -207,7 +203,7 @@ void disable_object_events ();
 /** Fix the stack so that it is correct (after stack 
  *  underflow or after method_events have been enabled). 
  */
-void get_call_trace (jthread* elem);
+void get_call_trace (jmpthread* elem);
 
 /** Fix the stack so that it is correct (after stack 
  *  underflow or after method_events have been enabled). 
@@ -227,11 +223,16 @@ void enable_monitor_events ();
 void disable_monitor_events ();
 
 /** Get the state of a thread. */
-jint get_thread_state (const jthread* jt);
+jint get_thread_state (const jmpthread* jt);
 
 /** Get the current gc level (number of times gc has occurred). */
 int get_current_gc_level ();
 
+JNIEnv * JavaVM_AttachCurrentThread ();
+int JavaVM_DetachCurrentThread ();
+
+int jvm_shutdown_thread_stop (JNIEnv* env);
+
 #endif /* JMP_H__ */
 
 /* Emacs Local Variables: */
