@@ -1,7 +1,9 @@
 #ifndef JMPTIME_H__
 #define JMPTIME_H__
 
-#include <sys/time.h>
+#ifdef HAVE_SYS_TIME_H
+ #include <sys/time.h>
+#endif
 #include <jni.h>
 #include <jvmpi.h>
 
@@ -22,6 +24,13 @@ extern jlong (*get_thread_time) (JVMPI_Interface* jvmpi);
 void jmptime_init (int absolute_time, const char* vm_version,
 		   const char* vm_vendor, const char* vm_name);
 
+/** Split the time value into second and nanons 
+ * @param td the current time
+ * @param jsec a pointer to where the seconds will be stored
+ * @param jnsec a pointer to where the nano seconds will be stored
+ */
+void jmptime_set_time_values (jlong td, jlong* jsec, jlong* jnsec);
+
 #endif /* JMPTIME_H__ */
 
 /* Emacs Local Variables: */
