@@ -214,6 +214,15 @@ void call_method_entry (JNIEnv* thread_env_id, jmethodID mid) {
     jvmpi->NotifyEvent (&event);
 }
 
+void call_method_entry2 (JNIEnv* thread_env_id, jobjectID oid, jmethodID mid) {
+    JVMPI_Event event;
+    event.event_type = JVMPI_EVENT_METHOD_ENTRY2;
+    event.env_id = thread_env_id;
+    event.u.method_entry2.method_id = mid;
+    event.u.method_entry2.obj_id = oid;
+    jvmpi->NotifyEvent (&event);
+}
+
 void call_method_exit (JNIEnv* thread_env_id, jmethodID mid) {
     JVMPI_Event event;
     event.event_type = JVMPI_EVENT_METHOD_EXIT;
