@@ -1,16 +1,15 @@
+#include <jmp-config.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
-#include <jvmpi.h>
-#include <translate.h>
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#ifdef HAVE_UNISTD_H
+ #include <unistd.h>
 #endif
 
-#include <method.h>
+#include <translate.h>
 #include <cls.h>
+#include <method.h>
 #include <mvector.h>
 
 method* method_new (const char* method_name, char* method_signature, 
@@ -85,59 +84,60 @@ int method_cmp_func (void* c1, void* c2) {
 void method_print (method* m) {
     fprintf (stdout, "    %s (%s), %d -> %d, %p\n", 
 	     m->method_name, m->method_signature,
-	     m->start_lineno, m->end_lineno, 
+	     PRINTF_JINT_CAST m->start_lineno, 
+	     PRINTF_JINT_CAST m->end_lineno, 
 	     m->method_id);    
 }
 
-inline void method_set_method_id (method* m, jmethodID method_id) {
+INLINE void method_set_method_id (method* m, jmethodID method_id) {
     m->method_id = method_id;
 }
 
-inline jmethodID method_get_method_id (const method* m) {
+INLINE jmethodID method_get_method_id (const method* m) {
     return m->method_id;
 }
 
-inline char* method_get_method_name (method* m) {
+INLINE char* method_get_method_name (method* m) {
     return m->method_name;
 }
 
-inline char* method_get_method_signature (method* m) {
+INLINE char* method_get_method_signature (method* m) {
     return m->method_signature;
 }
 
-inline char* method_get_method_jmpname (method* m) {
+INLINE char* method_get_method_jmpname (method* m) {
     return m->jmpname;
 }
 
-inline jobjectID method_get_class_id (method* m) {
+INLINE jobjectID method_get_class_id (method* m) {
     return cls_get_class_id (m->owner);
 }
 
-inline unsigned method_get_entered (method* m) {
+INLINE unsigned method_get_entered (method* m) {
     return m->entered;
 }
 
-inline long method_get_calls (method* m) {
+INLINE long method_get_calls (method* m) {
     return m->calls;
 }
 
-inline long method_get_restore_calls (method* m) {
+INLINE long method_get_restore_calls (method* m) {
     return m->restore_calls;
 }
 
-inline methodtime* method_get_time_used (method* m) {
+INLINE methodtime* method_get_time_used (method* m) {
     return &m->time_used;
 }
 
-inline methodtime* method_get_restore_time (method* m) {
+INLINE methodtime* method_get_restore_time (method* m) {
     return &m->restore_time;
 }
 
-inline cls* method_get_owner (method* m) {
+INLINE cls* method_get_owner (method* m) {
     return m->owner;
 }
 
-inline void method_reset_count (method* m) {
+INLINE void method_reset_count (method* m) {
     m->restore_calls += m->calls;
     m->calls = 0;
     m->restore_time.tv += m->time_used.tv;
@@ -151,7 +151,7 @@ inline void method_reset_count (method* m) {
     m->modified = 1;
 }
 
-inline void method_restore_count (method* m) {
+INLINE void method_restore_count (method* m) {
     m->calls += m->restore_calls;
     m->restore_calls = 0;
     m->time_used.tv += m->restore_time.tv;
@@ -165,21 +165,21 @@ inline void method_restore_count (method* m) {
     m->modified = 1;
 }
 
-inline int method_check_modified (method* m) {
+INLINE int method_check_modified (method* m) {
     return m->modified;
 }
 
-inline void method_set_modified (method* m, int flag) {
+INLINE void method_set_modified (method* m, int flag) {
     m->modified = flag;
 }
 
 /** Returns the number of objects allocated by this method */
-inline int method_get_allocated_objects (method* m) {
+INLINE int method_get_allocated_objects (method* m) {
     return m->allocated_objects;
 }
 
 /** Returns the number of bytes used for allocating objects by this method */
-inline jlong method_get_allocated_memory (method* m) {
+INLINE jlong method_get_allocated_memory (method* m) {
     return m->allocated_memory;
 }
 
