@@ -55,64 +55,64 @@ int method_cmp_func (void* c1, void* c2);
 void method_print (method* c);
 
 /** Set the method id of the given method. */
-inline void method_set_method_id (method* m, jmethodID method_id);
+INLINE void method_set_method_id (method* m, jmethodID method_id);
 
 /** Get the method id from the given method. */
-inline jmethodID method_get_method_id (const method* m);
+INLINE jmethodID method_get_method_id (const method* m);
 
 /** Get the method name from the given method. */
-inline char* method_get_method_name (method* m);
+INLINE char* method_get_method_name (method* m);
 
 /** Get the method signature from the given method. */
-inline char* method_get_method_signature (method* m);
+INLINE char* method_get_method_signature (method* m);
 
 /** Get the human readable name and signature. */
-inline char* method_get_method_jmpname (method* m);
+INLINE char* method_get_method_jmpname (method* m);
 
 /** Get the line number this method starts on. */
-inline jint method_get_method_start_line_number (method* m);
+INLINE jint method_get_method_start_line_number (method* m);
 
 /** Get the line number this method ends on. */
-inline jint method_get_method_end_line_number (method* m);
+INLINE jint method_get_method_end_line_number (method* m);
 
 /** Get the class id from the given method. */
-inline jobjectID method_get_class_id (method* m);
+INLINE jobjectID method_get_class_id (method* m);
 
 /** Get the number of calls to the method. */
-inline long method_get_calls (method* m);
+INLINE long method_get_calls (method* m);
 
 /** Get the number of method is in current stack traces. */
-inline unsigned method_get_entered (method* m);
+INLINE unsigned method_get_entered (method* m);
 
 /** Get the number of calls to the method. */
-inline long method_get_restore_calls (method* m);
+INLINE long method_get_restore_calls (method* m);
 
 /** Get the time used by the given method. */
-inline methodtime* method_get_time_used (method* m);
+INLINE methodtime* method_get_time_used (method* m);
 
 /** Get the time used by the given method. */
-inline methodtime* method_get_restore_time (method* m);
+INLINE methodtime* method_get_restore_time (method* m);
 
 /** Get the owner of this method. */
-inline cls* method_get_owner (method* m);
+INLINE cls* method_get_owner (method* m);
 
 /** Reset counters to zero. */
-inline void method_reset_count (method* m);
+INLINE void method_reset_count (method* m);
 
 /** Restore counters to real values. */
-inline void method_restore_count (method* m);
+INLINE void method_restore_count (method* m);
 
 /** Check if this method has changed since last call. */
-inline int method_check_modified (method* m);
+INLINE int method_check_modified (method* m);
 
 /** Set updated status of this method. */
-inline void method_set_modified (method* m, int flag);
+INLINE void method_set_modified (method* m, int flag);
 
 /** Returns the number of objects allocated by this method */
-inline int method_get_allocated_objects (method* m);
+INLINE int method_get_allocated_objects (method* m);
 
 /** Returns the number of bytes used for allocating objects by this method */
-inline jlong method_get_allocated_memory (method* m);
+INLINE jlong method_get_allocated_memory (method* m);
 
 #endif /* METHOD_H__ */
 
