@@ -1,11 +1,8 @@
+#include <jmp-config.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <jvmpi.h>
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 #include <obj.h>
 
@@ -45,38 +42,39 @@ int obj_cmp_func (void* c1, void* c2) {
 
 void obj_print (obj* o) {
     fprintf (stdout, "OBJECT (%p): arena: %d, class_id: %p, is_array: %d, size: %d, obj_id: %p\n", 
-	     o, o->arena_id, cls_get_class_id (o->clz), o->is_array, o->size, o->obj_id);
+	     o, PRINTF_JINT_CAST o->arena_id, cls_get_class_id (o->clz),
+	     PRINTF_JINT_CAST o->is_array, PRINTF_JINT_CAST o->size, o->obj_id);
 }
 
-inline jobjectID obj_get_object_id (obj* o) {
+INLINE jobjectID obj_get_object_id (obj* o) {
     return o->obj_id;
 }
 
-inline void obj_set_object_id (obj* o, jobjectID obj_id) {
+INLINE void obj_set_object_id (obj* o, jobjectID obj_id) {
     o->obj_id = obj_id;
 }
 
-inline cls* obj_get_class (obj* o) {
+INLINE cls* obj_get_class (obj* o) {
     return o->clz;
 }
 
-inline jobjectID obj_get_class_id (obj* o) {
+INLINE jobjectID obj_get_class_id (obj* o) {
     return cls_get_class_id (o->clz);
 }
 
-inline jint obj_get_size (obj* o) {
+INLINE jint obj_get_size (obj* o) {
     return o->size;
 }
 
-inline void obj_set_arena_id (obj* o, jint arena_id) {
+INLINE void obj_set_arena_id (obj* o, jint arena_id) {
     o->arena_id = arena_id;
 }
 
-inline int obj_get_reset_level (obj* o) {
+INLINE int obj_get_reset_level (obj* o) {
     return o->reset_level;
 }
 
-inline int obj_get_gc_level (obj* o) {
+INLINE int obj_get_gc_level (obj* o) {
     return o->gc_level;
 }
 
