@@ -39,28 +39,28 @@ int obj_cmp_func (void* c1, void* c2);
 void obj_print (obj* c);
 
 /** Get the id of the given object. */
-inline jobjectID obj_get_object_id (obj* o);
+INLINE jobjectID obj_get_object_id (obj* o);
 
 /** Set the id of the given object. */
-inline void obj_set_object_id (obj* o, jobjectID obj_id);
+INLINE void obj_set_object_id (obj* o, jobjectID obj_id);
 
 /** Get the class of the given object. */
-inline cls* obj_get_class (obj* o);
+INLINE cls* obj_get_class (obj* o);
 
 /** Get the class id of the given object. */
-inline jobjectID obj_get_class_id (obj* o);
+INLINE jobjectID obj_get_class_id (obj* o);
 
 /** Get the size of the given object. */
-inline jint obj_get_size (obj* o);
+INLINE jint obj_get_size (obj* o);
 
 /** Set the arena id of the given object. */
-inline void obj_set_arena_id (obj* o, jint arena_id);
+INLINE void obj_set_arena_id (obj* o, jint arena_id);
 
 /** Get the reset level that the object was allocated at. */
-inline int obj_get_reset_level (obj* o);
+INLINE int obj_get_reset_level (obj* o);
 
 /** Get the gc level that the object was allocated at. */
-inline int obj_get_gc_level (obj* o);
+INLINE int obj_get_gc_level (obj* o);
 
 #endif /* OBJ_H__ */
 
