@@ -1,11 +1,8 @@
+#include <jmp-config.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <jvmpi.h>
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 #include <obj.h>
 #include <objectstore.h>
