@@ -1,9 +1,15 @@
+#include <jmp-config.h>
+
 #include <stdio.h>
 #include <stdlib.h>
-#include <timerstack.h>
-#include <ui.h>
+
 #include <jmp.h>
-#include <jvmpi.h>
+#include <timerstack.h>
+#ifdef HAVE_WIN32COMPAT_H
+ #include <win32compat.h>
+#endif
+
+#include <ui_gtk.h>
 
 static int need_lock = 0;
 
@@ -56,13 +62,13 @@ void timerstacks_set_need_locks (int i) {
 /** Lock a given timerstack */
 void timerstack_lock (timerstack *s) {
     if (need_lock)
-	jmp_lock_monitor (s->monitor);
+	jmp_lock_monitor (s->monitor, MONITOR_AGENT);
 }
 
 /** Unlock a given timerstack */
 void timerstack_unlock(timerstack *s) {
     if (need_lock)
-	jmp_unlock_monitor (s->monitor);
+	jmp_unlock_monitor (s->monitor, MONITOR_AGENT);
 }
 
 /** Expand the given stack.
