@@ -5,6 +5,7 @@
 #define TIMERSTACK_H__
 
 #include <jmp.h>
+#include <monitor.h>
 #include <method.h>
 #include <methodtime.h>
 
@@ -29,7 +30,7 @@ struct timerstack {
     jlong            contendtime;  /** The time this thread has spend waiting for locks.. */
     obj*             waiting;      /** The object this thread is waiting on. */
     jlong            timeout;      /** wait timeout. */
-    JVMPI_RawMonitor monitor;      /** The monitor for multi threaded access. */    
+    monitor_t        monitor;      /** The monitor for multi threaded access. */    
 };
 
 /** Create a new stack with a minimun size of size. 
